# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import analytic
from . import account_move
from . import account_move_line
from . import chart_template
from . import crm_team
from . import payment_provider
from . import payment_transaction
from . import product_category
from . import product_document
from . import product_product
from . import product_template
from . import res_company
from . import res_partner
from . import sale_order
from . import sale_order_line
from . import utm_campaign
